Spreadsheet Formats
===================

Handlers for spreadsheet and office-style table formats.

.. autosummary::
   :toctree: generated

   etlplus.file.numbers
   etlplus.file.ods
   etlplus.file.wks
   etlplus.file.xls
   etlplus.file.xlsm
   etlplus.file.xlsx
